@@ -4,6 +4,8 @@
 import logging
 import time
 import threading
+import pkg_resources
+import json
 from velbus.parser import VelbusParser
 from velbus.connections.socket import SocketConnection
 from velbus.connections.serial import VelbusUSBConnection
@@ -27,11 +29,12 @@ class Controller(object):
     """
 
     def __init__(self, port):
-        self.logger = logging.getLogger('velbus')
+        self.logger = logging.getLogger("velbus")
         self.parser = VelbusParser(self)
         self.__subscribers = []
         self.__scan_callback = None
         self._modules = {}
+        self._loadModuleData()
         if ":" in port:
             self.connection = SocketConnection(port, self)
         else:
@@ -96,7 +99,7 @@ class Controller(object):
             Callback when scan is finished
             """
             time.sleep(3)
-            logging.info('Scan finished')
+            logging.info("Scan finished")
             self._nb_of_modules_loaded = 0
             self._load_finished = False
 
@@ -129,8 +132,8 @@ class Controller(object):
                         del self._modules[module]
                     callback()
 
-            # 60 second timeout for loading modules
-            self.load_timeout = threading.Timer(60, timeout_expired).start()
+            # 180 second timeout for loading modules
+            self.load_timeout = threading.Timer(180, timeout_expired).start()
             for module in self._modules:
                 self._modules[module].load(module_loaded)
 
@@ -155,25 +158,16 @@ class Controller(object):
         :return: None
         """
         self.logger.info("New message: " + str(message))
-        if isinstance(message, BusActiveMessage):
-            self.logger.info("Velbus active message received")
-        if isinstance(message, ReceiveReadyMessage):
-            self.logger.info("Velbus receive ready message received")
-        if isinstance(message, BusOffMessage):
-            self.logger.error("Velbus bus off message received")
-        if isinstance(message, ReceiveBufferFullMessage):
-            self.logger.error("Velbus receive buffer full message received")
         if isinstance(message, ModuleTypeMessage):
             self.logger.debug(
-                "Module type response received from address "
-                + str(message.address)
+                "Module type response received from address " + str(message.address)
             )
             name = message.module_name()
             address = message.address
             m_type = message.module_type
             if name == "Unknown":
                 self.logger.warning(
-                    "Unknown module (code: " + str(message.module_type) + ')'
+                    "Unknown module (code: " + str(message.module_type) + ")"
                 )
                 return
             if name in ModuleRegistry:
@@ -181,49 +175,33 @@ class Controller(object):
                 self._modules[address] = module
             else:
                 self.logger.warning("Module " + name + " is not yet supported")
-        if isinstance(message, ModuleSubTypeMessage):
+        elif isinstance(message, ModuleSubTypeMessage):
             self.logger.debug(
-                "Module subtype response received from address "
-                + str(message.address)
+                "Module subtype response received from address " + str(message.address)
             )
             name = message.module_name()
             address = message.address
             m_type = message.module_type
             if name == "Unknown":
                 self.logger.warning(
-                    "Unknown module (code: " + str(message.module_type) + ')'
+                    "Unknown module (code: " + str(message.module_type) + ")"
                 )
                 return
             if "SUB_" + name in ModuleRegistry:
                 subname = "SUB_" + name
                 if message.sub_address_1 != 0xFF:
                     module = ModuleRegistry[subname](
-                        m_type,
-                        subname,
-                        message.sub_address_1,
-                        address,
-                        1,
-                        self,
+                        m_type, subname, message.sub_address_1, address, 1, self,
                     )
                     self._modules[message.sub_address_1] = module
                 if message.sub_address_2 != 0xFF:
                     module = ModuleRegistry[subname](
-                        m_type,
-                        subname,
-                        message.sub_address_2,
-                        address,
-                        2,
-                        self,
+                        m_type, subname, message.sub_address_2, address, 2, self,
                     )
                     self._modules[message.sub_address_2] = module
                 if message.sub_address_3 != 0xFF:
                     module = ModuleRegistry[subname](
-                        m_type,
-                        subname,
-                        message.sub_address_3,
-                        address,
-                        3,
-                        self,
+                        m_type, subname, message.sub_address_3, address, 3, self,
                     )
                     self._modules[message.sub_address_3] = module
                 if (
@@ -233,18 +211,22 @@ class Controller(object):
                     and name != "VMBELO"
                 ):
                     module = ModuleRegistry[subname](
-                        m_type,
-                        subname,
-                        message.sub_address_4,
-                        address,
-                        4,
-                        self,
+                        m_type, subname, message.sub_address_4, address, 4, self,
                     )
                     self._modules[message.sub_address_4] = module
             else:
                 self.logger.warning(
                     "Module " + name + " does not yet support sub modules"
                 )
+        elif isinstance(message, BusActiveMessage):
+            self.logger.info("Velbus active message received")
+        elif isinstance(message, ReceiveReadyMessage):
+            self.logger.info("Velbus receive ready message received")
+        elif isinstance(message, BusOffMessage):
+            self.logger.error("Velbus bus off message received")
+        elif isinstance(message, ReceiveBufferFullMessage):
+            self.logger.error("Velbus receive buffer full message received")
+        # notify everyone who requests it
         for subscriber in self.__subscribers:
             subscriber(message)
 
@@ -261,3 +243,8 @@ class Controller(object):
         self.send(SetRealtimeClock())
         self.send(SetDate())
         self.send(SetDaylightSaving())
+
+    def _loadModuleData(self):
+        filepath = pkg_resources.resource_filename(__name__, "data.json")
+        with open(filepath) as json_file:
+            self._module_data = json.load(json_file)
